@@ -13,10 +13,20 @@ use Data::Object::ClassHas;
 
 extends 'Nano::Node';
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 # ATTRIBUTES
 
+has orders => (
+  is => 'ro',
+  isa => 'ArrayRef[CodeRef]',
+  new => 1,
+);
+
+fun new_orders($self) {
+  []
+}
+
 has scopes => (
   is => 'ro',
   isa => 'ArrayRef[CodeRef]',
@@ -42,10 +52,9 @@ fun new_type($self) {
 
 method add(HashRef $data) {
   my $object = $self->nano->reify($self->type, $data);
-  my $serial = $object->serialize;
-  my $lookup = $self->nano->lookup($self->id);
-  my $domain = $lookup->set($object->id);
-  $domain->merge(object => $serial);
+  my $table = $self->nano->table($self->id);
+  my $keyval = $table->set($object->id);
+  $keyval->send($object->serialize);
   return $object;
 }
 
@@ -57,16 +66,10 @@ method count() {
   return $self->search->count;
 }
 
-method del(Str $name) {
-  my $lookup = $self->nano->lookup($self->id);
-  my $object = $self->get($name);
-  $lookup->del($name);
-  return $object;
-}
-
 method drop() {
-  my $lookup = $self->nano->lookup($self->id);
-  $lookup->drop;
+  my $table = $self->nano->table($self->id);
+  $table->drop;
+  $self->next::method;
   return $self;
 }
 
@@ -75,9 +78,9 @@ method first() {
 }
 
 method get(Str $name) {
-  my $lookup = $self->nano->lookup($self->id);
-  my $domain = $lookup->get($name) or return undef;
-  my $object = $domain->get('object');
+  my $table = $self->nano->table($self->id);
+  my $keyval = $table->get($name) or return undef;
+  my $object = $keyval->recv or return undef;
   return $self->nano->object($object);
 }
 
@@ -85,12 +88,12 @@ method last() {
   return $self->search->last;
 }
 
-method next() {
-  return $self->search->next;
-}
-
-method prev() {
-  return $self->search->prev;
+method order(CodeRef $callback) {
+  my $instance = ref($self)->new(
+    %{$self},
+    orders => [@{$self->orders}, $callback],
+  );
+  return $instance;
 }
 
 method scope(CodeRef $callback) {
@@ -103,9 +106,10 @@ method scope(CodeRef $callback) {
 
 method search() {
   require Nano::Search; Nano::Search->new(
+    orders => $self->orders,
     scopes => $self->scopes,
     nodes => $self,
-  )
+  );
 }
 
 method serialize() {
@@ -118,10 +122,9 @@ method serialize() {
 }
 
 method set(Node $object) {
-  my $serial = $object->serialize;
-  my $lookup = $self->nano->lookup($self->id);
-  my $domain = $lookup->set($object->id);
-  $domain->merge(object => $serial);
+  my $table = $self->nano->table($self->id);
+  my $keyval = $table->set($object->id);
+  $keyval->send($object->serialize);
   return $object;
 }
 
@@ -182,6 +185,14 @@ This package has the following attributes:
 
 =cut
 
+=head2 orders
+
+  orders(ArrayRef[CodeRef])
+
+This attribute is read-only, accepts C<(ArrayRef[CodeRef])> values, and is optional.
+
+=cut
+
 =head2 scopes
 
   scopes(ArrayRef[CodeRef])
@@ -261,25 +272,6 @@ the results.
 
 =cut
 
-=head2 del
-
-  del(Str $name) : Maybe[Object]
-
-The del method removes the object from the index and returns the object (if
-found).
-
-=over 4
-
-=item del example #1
-
-  # given: synopsis
-
-  my $result = $nodes->del('0000001');
-
-=back
-
-=cut
-
 =head2 drop
 
   drop() : Object
@@ -354,39 +346,24 @@ the result.
 
 =cut
 
-=head2 next
+=head2 order
 
-  next() : Maybe[Object]
+  order(CodeRef $callback) : Object
 
-The next method proxies to the attached L<Nano::Search> instance and returns
-the result.
+The order method registers a sort order (search ordering) and returns a new
+invocant instance.
 
 =over 4
 
-=item next example #1
+=item order example #1
 
   # given: synopsis
 
-  my $next = $nodes->next;
+  $nodes = $nodes->order(sub {
+    my ($a, $b) = @_;
 
-=back
-
-=cut
-
-=head2 prev
-
-  prev() : Maybe[Object]
-
-The prev method proxies to the attached L<Nano::Search> instance and returns
-the result.
-
-=over 4
-
-=item prev example #1
-
-  # given: synopsis
-
-  my $prev = $nodes->prev;
+    $a->id cmp $b->id
+  });
 
 =back
 
