@@ -11,7 +11,7 @@ use base 'Data::Object::Types::Library';
 
 extends 'Types::Standard';
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 register {
   name => 'Nano',
@@ -37,18 +37,6 @@ register {
   validation => is_instance_of('Nano::Search'),
 };
 
-register {
-  name => 'Cursor',
-  parent => 'Object',
-  validation => is_instance_of('Zing::Cursor'),
-};
-
-register {
-  name => 'Domain',
-  parent => 'Object',
-  validation => is_instance_of('Zing::Domain'),
-};
-
 register {
   name => 'Env',
   parent => 'Object',
@@ -56,9 +44,15 @@ register {
 };
 
 register {
-  name => 'Lookup',
+  name => 'KeyVal',
   parent => 'Object',
-  validation => is_instance_of('Zing::Lookup'),
+  validation => is_instance_of('Zing::KeyVal'),
+};
+
+register {
+  name => 'Table',
+  parent => 'Object',
+  validation => is_instance_of('Zing::Table'),
 };
 
 1;
@@ -108,79 +102,6 @@ This package declares the following type constraints:
 
 =cut
 
-=head2 cursor
-
-  Cursor
-
-This type is defined in the L<Nano::Types> library.
-
-=over 4
-
-=item cursor parent
-
-  Object
-
-=back
-
-=over 4
-
-=item cursor composition
-
-  InstanceOf["Zing::Cursor"]
-
-=back
-
-=over 4
-
-=item cursor example #1
-
-  # given: synopsis
-
-  use Zing::Cursor;
-  use Zing::Lookup;
-
-  my $cursor = Zing::Cursor->new(lookup => Zing::Lookup->new(name => 'users'));
-
-=back
-
-=cut
-
-=head2 domain
-
-  Domain
-
-This type is defined in the L<Nano::Types> library.
-
-=over 4
-
-=item domain parent
-
-  Object
-
-=back
-
-=over 4
-
-=item domain composition
-
-  InstanceOf["Zing::Domain"]
-
-=back
-
-=over 4
-
-=item domain example #1
-
-  # given: synopsis
-
-  use Zing::Domain;
-
-  my $domain = Zing::Domain->new(name => 'user-12345');
-
-=back
-
-=cut
-
 =head2 env
 
   Env
@@ -217,15 +138,15 @@ This type is defined in the L<Nano::Types> library.
 
 =cut
 
-=head2 lookup
+=head2 keyval
 
-  Lookup
+  KeyVal
 
 This type is defined in the L<Nano::Types> library.
 
 =over 4
 
-=item lookup parent
+=item keyval parent
 
   Object
 
@@ -233,21 +154,21 @@ This type is defined in the L<Nano::Types> library.
 
 =over 4
 
-=item lookup composition
+=item keyval composition
 
-  InstanceOf["Zing::Lookup"]
+  InstanceOf["Zing::KeyVal"]
 
 =back
 
 =over 4
 
-=item lookup example #1
+=item keyval example #1
 
   # given: synopsis
 
-  use Zing::Lookup;
+  use Zing::KeyVal;
 
-  my $lookup = Zing::Lookup->new(name => 'users');
+  my $domain = Zing::KeyVal->new(name => 'user-12345');
 
 =back
 
@@ -398,6 +319,42 @@ This type is defined in the L<Nano::Types> library.
 
 =cut
 
+=head2 table
+
+  Table
+
+This type is defined in the L<Nano::Types> library.
+
+=over 4
+
+=item table parent
+
+  Object
+
+=back
+
+=over 4
+
+=item table composition
+
+  InstanceOf["Zing::Table"]
+
+=back
+
+=over 4
+
+=item table example #1
+
+  # given: synopsis
+
+  use Zing::Table;
+
+  my $lookup = Zing::Table->new(name => 'users');
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Al Newkirk, C<awncorp@cpan.org>
